Module: KubeMQ::Queues::DownstreamRequestType Private

Defined in:
lib/kubemq/queues/queue_poll_request.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

Internal constants for downstream queue request types.

Used by the transport layer to encode transaction actions sent over the downstream gRPC stream.

Constant Summary collapse

GET =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Poll for new messages.

1
ACK_ALL =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Acknowledge all messages in the transaction.

2
ACK_RANGE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Acknowledge a specific range of messages by sequence.

3
NACK_ALL =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Negative-acknowledge all messages in the transaction.

4
NACK_RANGE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Negative-acknowledge a specific range of messages by sequence.

5
REQUEUE_ALL =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Requeue all messages to a different channel.

6
REQUEUE_RANGE =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Requeue a specific range of messages to a different channel.

7
ACTIVE_OFFSETS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Query active message offsets.

8
TRANSACTION_STATUS =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Query current transaction status.

9
CLOSE_BY_CLIENT =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Client-initiated stream close.

10
CLOSE_BY_SERVER =

This constant is part of a private API. You should avoid using this constant if possible, as it may be removed or be changed in the future.

Server-initiated stream close.

11